@@ -66,10 +66,10 @@ class configure(object):
 
         # Add the annotations for the new arguments to the annotations that were passed in
         self.ann.update(dict(
-             zdesk_email=("zendesk login email", "option", 'e', None, None, "EMAIL"),
-             zdesk_password=("zendesk password or token", "option", 'p', None, None, "PASSWD"),
-             zdesk_url=("zendesk instance URL", "option", 'u', None, None, "URL"),
-             zdesk_token=("specify if password is a Zendesk token", "flag", 't'),
+             zdesk_email=("zendesk login email", "option", None, None, None, "EMAIL"),
+             zdesk_password=("zendesk password or token", "option", None, None, None, "PW"),
+             zdesk_url=("zendesk instance URL", "option", None, None, None, "URL"),
+             zdesk_token=("specify if password is a zendesk token", "flag", None, bool),
         ))
 
         # Define and exec the wrapping function that will be returned
